@@ -11,14 +11,14 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: tkMacOSXDraw.c,v 1.32 2007/12/13 15:27:09 dgp Exp $
  */
 
 #include "tkMacOSXPrivate.h"
 #include "tkMacOSXDebug.h"
 #include "xbytes.h"
 
-#include "tclInt.h" /* for Tcl_CreateNamespace() */
-
 /*
 #ifdef TK_MAC_DEBUG
 #define TK_MAC_DEBUG_DRAWING
@@ -43,7 +43,7 @@ int tkMacOSXUseCGDrawing = 1;
 
 int tkPictureIsOpen;
 
-static PixPatHandle penPat = NULL, tmpPixPat = NULL;
+static PixPatHandle penPat = NULL;
 
 static int cgAntiAliasLimit = 0;
 #define notAA(w) ((w) < cgAntiAliasLimit)
@@ -340,7 +340,7 @@ end:
  *----------------------------------------------------------------------
  */
 
-int
+void
 TkPutImage(
     unsigned long *colors,	/* Unused on Macintosh. */
     int ncolors,		/* Unused on Macintosh. */
@@ -360,7 +360,7 @@ TkPutImage(
 
     display->request++;
     if (!TkMacOSXSetupDrawingContext(d, gc, 0, &dc)) {
-	return BadDrawable;
+	return;
     }
     if (dc.context) {
 	TkMacOSXDbgMsg("Ignored CG drawing of XImage");
@@ -532,7 +532,6 @@ TkPutImage(
 	}
     }
     TkMacOSXRestoreDrawingContext(&dc);
-    return Success;
 }
 
 /*
@@ -551,7 +550,7 @@ TkPutImage(
  *----------------------------------------------------------------------
  */
 
-int
+void
 XDrawLines(
     Display *display,		/* Display. */
     Drawable d,			/* Draw on this. */
@@ -565,12 +564,16 @@ XDrawLines(
     int i, lw = gc->line_width;
 
     if (npoints < 2) {
-	return BadValue;
+	/*
+	 * TODO: generate BadValue error.
+	 */
+
+	return;
     }
 
     display->request++;
     if (!TkMacOSXSetupDrawingContext(d, gc, tkMacOSXUseCGDrawing, &dc)) {
-	return BadDrawable;
+	return;
     }
     if (dc.context) {
 	double prevx, prevy;
@@ -611,7 +614,6 @@ XDrawLines(
 	}
     }
     TkMacOSXRestoreDrawingContext(&dc);
-    return Success;
 }
 
 /*
@@ -900,7 +902,7 @@ XDrawRectangles(
  *----------------------------------------------------------------------
  */
 
-int
+void
 XFillRectangles(
     Display* display,		/* Display. */
     Drawable d,			/* Draw on this. */
@@ -915,7 +917,7 @@ XFillRectangles(
 
     display->request++;
     if (!TkMacOSXSetupDrawingContext(d, gc, tkMacOSXUseCGDrawing, &dc)) {
-	return BadDrawable;
+	return;
     }
     if (dc.context) {
 	CGRect rect;
@@ -942,7 +944,6 @@ XFillRectangles(
 	}
     }
     TkMacOSXRestoreDrawingContext(&dc);
-    return Success;
 }
 
 /*
@@ -1501,27 +1502,20 @@ TkMacOSXSetUpGraphicsPort(
     GC gc,			/* GC to apply to current port. */
     GWorldPtr destPort)
 {
-    CGrafPtr savePort;
-    Boolean portChanged;
-
-    portChanged = QDSwapPort(destPort, &savePort);
     PenNormal();
     if (gc) {
-	if (!penPat) {
-	    if (!tmpPixPat) {
-		penPat = NewPixPat();
-	    } else {
-		penPat = tmpPixPat;
-		tmpPixPat = NULL;
-	    }
+	if (penPat == NULL) {
+	    penPat = NewPixPat();
 	}
 	TkMacOSXSetColorInPort(gc->foreground, 1, penPat, destPort);
-	PenPixPat(penPat);
+	SetPortPenPixPat(destPort, penPat);
 	if(gc->function == GXxor) {
-	    PenMode(patXor);
+	    SetPortPenMode(destPort, patXor);
 	}
 	if (gc->line_width > 1) {
-	    PenSize(gc->line_width, gc->line_width);
+	    Point s = {gc->line_width, gc->line_width};
+
+	    SetPortPenSize(destPort, s);
 	}
 	if (gc->line_style != LineSolid) {
 	    /*
@@ -1530,9 +1524,6 @@ TkMacOSXSetUpGraphicsPort(
 	     */
 	}
     }
-    if (portChanged) {
-	QDSwapPort(savePort, NULL);
-    }
 }
 
 /*
@@ -1585,7 +1576,7 @@ TkMacOSXSetupDrawingContext(
 	goto end;
     }
     if (useCG) {
-	dc.context = macDraw->context;
+	dc.context = macDraw->context;;
     }
     if (!dc.context || !(macDraw->flags & TK_IS_PIXMAP)) {
 	dc.port = TkMacOSXGetDrawablePort(d);
@@ -1752,11 +1743,7 @@ TkMacOSXRestoreDrawingContext(
 	    DisposeRgn(dcPtr->saveClip);
 	}
 	if (dcPtr->penPat) {
-	    if (!tmpPixPat) {
-		tmpPixPat = dcPtr->penPat;
-	    } else {
-		DisposePixPat(dcPtr->penPat);
-	    }
+	    DisposePixPat(dcPtr->penPat);
 	}
 	if (dcPtr->saveState) {
 	    ChkErr(SetThemeDrawingState, dcPtr->saveState, true);
@@ -1769,7 +1756,7 @@ TkMacOSXRestoreDrawingContext(
 	QDSwapPort(dcPtr->savePort, NULL);
     }
 #ifdef TK_MAC_DEBUG
-    bzero(dcPtr, sizeof(TkMacOSXDrawingContext));
+    bzero(dcPtr, sizeof(dcPtr));
 #endif /* TK_MAC_DEBUG */
 }
 
