@@ -53,6 +53,8 @@
  *	acting in its behalf permission to use and distribute the
  *	software in accordance with the terms specified in this
  *	license.
+ *
+ * RCS: @(#) $Id: tkMacOSXWindowEvent.c,v 1.31 2007/12/13 15:27:10 dgp Exp $
  */
 
 #include "tkMacOSXPrivate.h"
@@ -125,7 +127,7 @@ TkMacOSXProcessApplicationEvent(
 		toggleHide = 1;
 		if (eventPtr->interp && Tcl_GetCommandInfo(eventPtr->interp,
 			"::tk::mac::OnHide", &dummy)) {
-		    Tcl_EvalEx(eventPtr->interp, "::tk::mac::OnHide", -1, TCL_EVAL_GLOBAL);
+		    Tcl_GlobalEval(eventPtr->interp, "::tk::mac::OnHide");
 		}
 	    }
 	    statusPtr->stopProcessing = 1;
@@ -135,7 +137,7 @@ TkMacOSXProcessApplicationEvent(
 		toggleHide = 0;
 		if (eventPtr->interp && Tcl_GetCommandInfo(eventPtr->interp,
 			"::tk::mac::OnShow", &dummy)) {
-		    Tcl_EvalEx(eventPtr->interp, "::tk::mac::OnShow", -1, TCL_EVAL_GLOBAL);
+		    Tcl_GlobalEval(eventPtr->interp, "::tk::mac::OnShow");
 		}
 	    }
 	    statusPtr->stopProcessing = 1;
@@ -416,7 +418,7 @@ TkMacOSXProcessWindowEvent(
 	    break;
     }
 
-    return eventFound;
+    return 0;
 }
 
 /*
@@ -896,7 +898,7 @@ TkWmProtocolEventProc(
 	    Tcl_Preserve((ClientData) protPtr);
 	    interp = protPtr->interp;
 	    Tcl_Preserve((ClientData) interp);
-	    result = Tcl_EvalEx(interp, protPtr->command, -1, TCL_EVAL_GLOBAL);
+	    result = Tcl_GlobalEval(interp, protPtr->command);
 	    if (result != TCL_OK) {
 		Tcl_AddErrorInfo(interp, "\n    (command for \"");
 		Tcl_AddErrorInfo(interp,
