@@ -10,6 +10,8 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * RCS: @(#) $Id: tkWinTest.c,v 1.14 2007/12/13 15:28:56 dgp Exp $
  */
 
 #include "tkWinInt.h"
@@ -22,11 +24,18 @@ HWND tkWinCurrentDialog;
 
 static int		TestclipboardObjCmd(ClientData clientData,
 			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *const objv[]);
+			    Tcl_Obj *CONST objv[]);
 static int		TestwineventCmd(ClientData clientData,
-			    Tcl_Interp *interp, int argc, const char **argv);
-int			TkplatformtestInit(Tcl_Interp *interp);
+			    Tcl_Interp *interp, int argc, CONST char **argv);
+static int		TestfindwindowObjCmd(ClientData clientData,
+			    Tcl_Interp *interp, int objc,
+			    Tcl_Obj *CONST objv[]);
+static int		TestgetwindowinfoObjCmd(ClientData clientData,
+			    Tcl_Interp *interp, int objc,
+			    Tcl_Obj *CONST objv[]);
+MODULE_SCOPE int	TkplatformtestInit(Tcl_Interp *interp);
 
+
 /*
  *----------------------------------------------------------------------
  *
@@ -53,9 +62,14 @@ TkplatformtestInit(
      */
 
     Tcl_CreateObjCommand(interp, "testclipboard", TestclipboardObjCmd,
-	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
+	    (ClientData) Tk_MainWindow(interp), NULL);
     Tcl_CreateCommand(interp, "testwinevent", TestwineventCmd,
-	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
+	    (ClientData) Tk_MainWindow(interp), NULL);
+    Tcl_CreateObjCommand(interp, "testfindwindow", TestfindwindowObjCmd,
+	    (ClientData) Tk_MainWindow(interp), NULL);
+    Tcl_CreateObjCommand(interp, "testgetwindowinfo", TestgetwindowinfoObjCmd,
+	    (ClientData) Tk_MainWindow(interp), NULL);
+
     return TCL_OK;
 }
 
@@ -83,14 +97,11 @@ AppendSystemError(
 {
     int length;
     WCHAR *wMsgPtr;
-    const char *msg;
+    char *msg;
     char id[TCL_INTEGER_SPACE], msgBuf[24 + TCL_INTEGER_SPACE];
     Tcl_DString ds;
     Tcl_Obj *resultPtr = Tcl_GetObjResult(interp);
 
-    if (Tcl_IsShared(resultPtr)) {
-	resultPtr = Tcl_DuplicateObj(resultPtr);
-    }
     length = FormatMessageW(FORMAT_MESSAGE_FROM_SYSTEM
 	    | FORMAT_MESSAGE_ALLOCATE_BUFFER, NULL, error,
 	    MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (WCHAR *) &wMsgPtr,
@@ -111,41 +122,36 @@ AppendSystemError(
     }
     if (length == 0) {
 	if (error == ERROR_CALL_NOT_IMPLEMENTED) {
-	    strcpy(msgBuf, "function not supported under Win32s");
+	    msg = "function not supported under Win32s";
 	} else {
 	    sprintf(msgBuf, "unknown error: %ld", error);
+	    msg = msgBuf;
 	}
-	msg = msgBuf;
     } else {
 	Tcl_Encoding encoding;
-	char *msgPtr;
 
 	encoding = Tcl_GetEncoding(NULL, "unicode");
-	Tcl_ExternalToUtfDString(encoding, (char *) wMsgPtr, -1, &ds);
+	msg = Tcl_ExternalToUtfDString(encoding, (char *) wMsgPtr, -1, &ds);
 	Tcl_FreeEncoding(encoding);
 	LocalFree(wMsgPtr);
 
-	msgPtr = Tcl_DStringValue(&ds);
 	length = Tcl_DStringLength(&ds);
 
 	/*
 	 * Trim the trailing CR/LF from the system message.
 	 */
 
-	if (msgPtr[length-1] == '\n') {
-	    --length;
+	if (msg[length-1] == '\n') {
+	    msg[--length] = 0;
 	}
-	if (msgPtr[length-1] == '\r') {
-	    --length;
+	if (msg[length-1] == '\r') {
+	    msg[--length] = 0;
 	}
-	msgPtr[length] = 0;
-	msg = msgPtr;
     }
 
     sprintf(id, "%ld", error);
-    Tcl_SetErrorCode(interp, "WINDOWS", id, msg, (char *) NULL);
+    Tcl_SetErrorCode(interp, "WINDOWS", id, msg, NULL);
     Tcl_AppendToObj(resultPtr, msg, length);
-    Tcl_SetObjResult(interp, resultPtr);
 
     if (length != 0) {
 	Tcl_DStringFree(&ds);
@@ -174,36 +180,37 @@ TestclipboardObjCmd(
     ClientData clientData,	/* Main window for application. */
     Tcl_Interp *interp,		/* Current interpreter. */
     int objc,			/* Number of arguments. */
-    Tcl_Obj *const objv[])	/* Argument values. */
+    Tcl_Obj *CONST objv[])	/* Argument values. */
 {
+    TkWindow *winPtr = (TkWindow *) clientData;
     HGLOBAL handle;
     char *data;
     int code = TCL_OK;
 
     if (objc != 1) {
-	Tcl_WrongNumArgs(interp, 1, objv, (char *) NULL);
+	Tcl_WrongNumArgs(interp, 1, objv, NULL);
 	return TCL_ERROR;
     }
     if (OpenClipboard(NULL)) {
 	/*
-	 * We could consider using CF_UNICODETEXT on NT, but then we
-	 * would have to convert it from External.  Instead we'll just
-	 * take this and do "bytestring" at the Tcl level for Unicode
-	 * inclusive text
+	 * We could consider using CF_UNICODETEXT on NT, but then we would
+	 * have to convert it from External. Instead we'll just take this and
+	 * do "bytestring" at the Tcl level for Unicode inclusive text
 	 */
+
 	handle = GetClipboardData(CF_TEXT);
 	if (handle != NULL) {
 	    data = GlobalLock(handle);
-	    Tcl_AppendResult(interp, data, (char *) NULL);
+	    Tcl_AppendResult(interp, data, NULL);
 	    GlobalUnlock(handle);
 	} else {
-	    Tcl_AppendResult(interp, "null clipboard handle", (char *) NULL);
+	    Tcl_AppendResult(interp, "null clipboard handle", NULL);
 	    code = TCL_ERROR;
 	}
 	CloseClipboard();
 	return code;
     } else {
-	Tcl_AppendResult(interp, "couldn't open clipboard: ", (char *) NULL);
+	Tcl_AppendResult(interp, "couldn't open clipboard: ", NULL);
 	AppendSystemError(interp, GetLastError());
 	return TCL_ERROR;
     }
@@ -232,7 +239,7 @@ TestwineventCmd(
     ClientData clientData,	/* Main window for application. */
     Tcl_Interp *interp,		/* Current interpreter. */
     int argc,			/* Number of arguments. */
-    const char **argv)		/* Argument strings. */
+    CONST char **argv)		/* Argument strings. */
 {
     HWND hwnd = 0;
     HWND child = 0;
@@ -265,6 +272,16 @@ TestwineventCmd(
 	return TCL_ERROR;
     }
 
+#if 0
+    TkpScanWindowId(interp, argv[1], &id);
+    if (
+#ifdef _WIN64
+	    (sscanf(string, "0x%p", &number) != 1) &&
+#endif /* _WIN64 */
+	    Tcl_GetInt(interp, string, (int *)&number) != TCL_OK) {
+	return TCL_ERROR;
+    }
+#endif
     hwnd = (HWND) strtol(argv[1], &rest, 0);
     if (rest == argv[1]) {
 	hwnd = FindWindow(NULL, argv[1]);
@@ -289,8 +306,6 @@ TestwineventCmd(
 	    child = GetWindow(child, GW_HWNDNEXT);
 	}
 	if (child == NULL) {
-	    Tcl_AppendResult(interp, "could not find a control matching \"",
-		argv[2], "\"", NULL);
 	    return TCL_ERROR;
 	}
     }
@@ -309,52 +324,158 @@ TestwineventCmd(
     }
 
     switch (message) {
-	case WM_GETTEXT: {
-	    Tcl_DString ds;
-	    char buf[256];
+    case WM_GETTEXT: {
+	Tcl_DString ds;
+	char buf[256];
 
-	    GetDlgItemText(hwnd, id, buf, 256);
-	    Tcl_ExternalToUtfDString(NULL, buf, -1, &ds);
-	    Tcl_AppendResult(interp, Tcl_DStringValue(&ds), NULL);
-	    Tcl_DStringFree(&ds);
-	    break;
-	}
-	case WM_SETTEXT: {
-	    Tcl_DString ds;
-	    BOOL result;
+	GetDlgItemText(hwnd, id, buf, 256);
+	Tcl_ExternalToUtfDString(NULL, buf, -1, &ds);
+	Tcl_AppendResult(interp, Tcl_DStringValue(&ds), NULL);
+	Tcl_DStringFree(&ds);
+	break;
+    }
+    case WM_SETTEXT: {
+	Tcl_DString ds;
 
-	    Tcl_UtfToExternalDString(NULL, argv[4], -1, &ds);
-	    result = SetDlgItemText(hwnd, id, Tcl_DStringValue(&ds));
-	    Tcl_DStringFree(&ds);
-	    if (result == 0) {
-		Tcl_SetResult(interp, "failed to send text to dialog: ", TCL_STATIC);
-		AppendSystemError(interp, GetLastError());
-		return TCL_ERROR;
-	    }
-	    break;
+	Tcl_UtfToExternalDString(NULL, argv[4], -1, &ds);
+	SetDlgItemText(hwnd, id, Tcl_DStringValue(&ds));
+	Tcl_DStringFree(&ds);
+	break;
+    }
+    case WM_COMMAND: {
+	char buf[TCL_INTEGER_SPACE];
+	if (argc < 5) {
+	    wParam = MAKEWPARAM(id, 0);
+	    lParam = (LPARAM)child;
 	}
-	case WM_COMMAND: {
-	    char buf[TCL_INTEGER_SPACE];
-	    if (argc < 5) {
-		wParam = MAKEWPARAM(id, 0);
-		lParam = (LPARAM)child;
-	    }
-	    sprintf(buf, "%d", (int) SendMessageA(hwnd, message, wParam, lParam));
-	    Tcl_SetResult(interp, buf, TCL_VOLATILE);
-	    break;
-	}
-	default: {
-	    char buf[TCL_INTEGER_SPACE];
+	sprintf(buf, "%d", SendMessage(hwnd, message, wParam, lParam));
+	Tcl_SetResult(interp, buf, TCL_VOLATILE);
+	break;
+    }
+    default: {
+	char buf[TCL_INTEGER_SPACE];
 
-	    sprintf(buf, "%d",
-		    (int) SendDlgItemMessage(hwnd, id, message, wParam, lParam));
-	    Tcl_SetResult(interp, buf, TCL_VOLATILE);
-	    break;
-	}
+	sprintf(buf, "%d",
+		SendDlgItemMessage(hwnd, id, message, wParam, lParam));
+	Tcl_SetResult(interp, buf, TCL_VOLATILE);
+	break;
+    }
     }
     return TCL_OK;
 }
 
+/*
+ *  testfindwindow title ?class?
+ *	Find a Windows window using the FindWindow API call. This takes the window
+ *	title and optionally the window class and if found returns the HWND and 
+ *	raises an error if the window is not found.
+ *	eg: testfindwindow Console TkTopLevel
+ *	    Can find the console window if it is visible.
+ *	eg: testfindwindow "TkTest #10201" "#32770"
+ *	    Can find a messagebox window with this title.
+ */
+
+static int
+TestfindwindowObjCmd(
+    ClientData clientData,	/* Main window for application. */
+    Tcl_Interp *interp,		/* Current interpreter. */
+    int objc,			/* Number of arguments. */
+    Tcl_Obj *CONST objv[])	/* Argument values. */
+{
+    TkWindow *winPtr = (TkWindow *) clientData;
+    const char *title = NULL, *class = NULL;
+    HWND hwnd = NULL;
+    int r = TCL_OK;
+
+    if (objc < 2 || objc > 3) {
+        Tcl_WrongNumArgs(interp, 1, objv, "title ?class?");
+        return TCL_ERROR;
+    }
+    title = Tcl_GetString(objv[1]);
+    if (objc == 3)
+        class = Tcl_GetString(objv[2]);
+    hwnd = FindWindowA(class, title);
+
+    if (hwnd == NULL) {
+	Tcl_SetObjResult(interp, Tcl_NewStringObj("failed to find window: ", -1));
+	AppendSystemError(interp, GetLastError());
+	r = TCL_ERROR;
+    } else {
+        Tcl_SetObjResult(interp, Tcl_NewLongObj((long)hwnd));
+    }
+    return r;
+    
+}
+
+static BOOL CALLBACK
+EnumChildrenProc(HWND hwnd, LPARAM lParam)
+{
+    Tcl_Obj *listObj = (Tcl_Obj *)lParam;
+    Tcl_ListObjAppendElement(NULL, listObj, Tcl_NewLongObj((long)hwnd));
+    return TRUE;
+}
+
+static int
+TestgetwindowinfoObjCmd(
+    ClientData clientData,
+    Tcl_Interp *interp,
+    int objc,
+    Tcl_Obj *CONST objv[])
+{
+    HWND hwnd = NULL;
+    Tcl_Obj *resObj = NULL, *classObj = NULL, *textObj = NULL;
+    Tcl_Obj *childrenObj = NULL;
+    char buf[512];
+    int cch, cchBuf = tkWinProcs->useWide ? 256 : 512;
+
+    if (objc != 2) {
+	Tcl_WrongNumArgs(interp, 1, objv, "hwnd");
+	return TCL_ERROR;
+    }
+
+    if (Tcl_GetLongFromObj(interp, objv[1], (long *)&hwnd) != TCL_OK)
+	return TCL_ERROR;
+    
+    if (tkWinProcs->useWide) {
+	cch = GetClassNameW(hwnd, (LPWSTR)buf, sizeof(buf)/sizeof(WCHAR));
+	classObj = Tcl_NewUnicodeObj((LPWSTR)buf, cch);
+    } else {
+	cch = GetClassNameA(hwnd, (LPSTR)buf, sizeof(buf));
+	classObj = Tcl_NewStringObj((LPSTR)buf, cch);
+    }
+    if (cch == 0) {
+    	Tcl_SetResult(interp, "failed to get class name: ", TCL_STATIC);
+    	AppendSystemError(interp, GetLastError());
+    	return TCL_ERROR;
+    }	
+
+    resObj = Tcl_NewListObj(0, NULL);
+    Tcl_ListObjAppendElement(interp, resObj, Tcl_NewStringObj("class", -1));
+    Tcl_ListObjAppendElement(interp, resObj, classObj);
+
+    Tcl_ListObjAppendElement(interp, resObj, Tcl_NewStringObj("id", -1));
+    Tcl_ListObjAppendElement(interp, resObj, 
+	Tcl_NewLongObj(GetWindowLong(hwnd, GWL_ID)));
+
+    cch = tkWinProcs->getWindowText(hwnd, (LPTSTR)buf, cchBuf);
+    if (tkWinProcs->useWide) {
+	textObj = Tcl_NewUnicodeObj((LPCWSTR)buf, cch);
+    } else {
+	textObj = Tcl_NewStringObj((LPCSTR)buf, cch);
+    }
+
+    Tcl_ListObjAppendElement(interp, resObj, Tcl_NewStringObj("text", -1));
+    Tcl_ListObjAppendElement(interp, resObj, textObj);
+
+    childrenObj = Tcl_NewListObj(0, NULL);
+    EnumChildWindows(hwnd, EnumChildrenProc, (LPARAM)childrenObj);
+    Tcl_ListObjAppendElement(interp, resObj, Tcl_NewStringObj("children", -1));
+    Tcl_ListObjAppendElement(interp, resObj, childrenObj);
+
+    Tcl_SetObjResult(interp, resObj);
+    return TCL_OK;
+}   
+
 /*
  * Local Variables:
  * mode: c
